@@ -35,18 +35,18 @@ class PXBlocker(object):
         headers = {'Content-Type': content_type}
 
         if action is px_constants.ACTION_CHALLENGE:
-            logger.debug('Challenge page is served')
+            logger.debug('Enforcing action: Challenge page is served')
             blocking_props = ctx.block_action_data
             blocking_response = blocking_props
 
         elif action is px_constants.ACTION_RATELIMIT:
-            logger.debug('Rate limit page is served')
+            logger.debug('Enforcing action: Rate limit page is served')
             blocking_props = None
             blocking_response = self.ratelimit_rendered_page
             status = '429 Too Many Requests'
 
         else:  # block
-            logger.debug('Block page is served')
+            logger.debug('Enforcing action: Block page is served')
             blocking_props = self.prepare_properties(ctx, config)
             blocking_response = self.mustache_renderer.render(px_template.get_template(px_constants.BLOCK_TEMPLATE),
                                                               blocking_props)
@@ -63,6 +63,7 @@ class PXBlocker(object):
             return page_response, headers, status
 
         if is_json_response:
+            logger.debug('Serving advanced blocking response')
             blocking_response = json.dumps(blocking_props)
 
         blocking_response = str(blocking_response)
@@ -75,6 +76,7 @@ class PXBlocker(object):
         custom_logo = config.custom_logo
         is_mobile_num = 1 if ctx.is_mobile else 0
         captcha_uri = 'captcha.js?a={}&u={}&v={}&m={}'.format(ctx.block_action, uuid, vid, is_mobile_num)
+        alt_captcha_src = '//{}/{}/{}'.format(px_constants.ALT_CAPTCHA_HOST, app_id, captcha_uri)
 
         if config.first_party and not ctx.is_mobile:
             prefix = app_id[2:]
@@ -87,18 +89,17 @@ class PXBlocker(object):
             host_url = px_constants.COLLECTOR_URL.format(app_id.lower())
 
         return {
-            'refId': uuid,
             'appId': app_id,
             'vid': vid,
             'uuid': uuid,
-            'customLogo': custom_logo,
+            'customLogo': custom_logo if custom_logo else '',
             'cssRef': config.css_ref,
             'jsRef': config.js_ref,
-            'logoVisibility': 'visible' if custom_logo is not None else 'hidden',
             'hostUrl': host_url,
             'jsClientSrc': js_client_src,
             'firstPartyEnabled': 'true' if config.first_party else 'false',
-            'blockScript': captcha_src
+            'blockScript': captcha_src,
+            'altBlockScript': alt_captcha_src
         }
 
     def is_json_response(self, ctx):
@@ -117,7 +118,7 @@ def parse_action(action):
     if 'b' == action:
         return 'block'
     elif 'j' == action:
-        return 'challege'
+        return 'challenge'
     elif 'r' == action:
         return 'ratelimit'
     else:
