@@ -10,15 +10,16 @@ class PxConfig(object):
         module_mode = config_dict.get('module_mode', px_constants.MODULE_MODE_MONITORING)
         custom_logo = config_dict.get('custom_logo', None)
         testing_mode = config_dict.get('testing_mode', False)
+        px_backend_host = config_dict.get('px_backend_url', None)
+        max_buffer_len = config_dict.get('max_buffer_len', 30)
         self._px_app_id = app_id
         self._blocking_score = config_dict.get('blocking_score', 100)
         self._debug_mode = debug_mode
         self._module_version = config_dict.get('module_version', px_constants.MODULE_VERSION)
         self._module_version = px_constants.MODULE_VERSION.format(' GAE') if os.environ.get('SERVER_SOFTWARE','').startswith('Google') else px_constants.MODULE_VERSION.format('')
         self._module_mode = module_mode
-        self._server_host = 'sapi.perimeterx.net' if app_id is None else px_constants.SERVER_URL.format(app_id.lower())
-        self._collector_host = 'collector.perimeterx.net' if app_id is None else px_constants.COLLECTOR_URL.format(
-            app_id.lower())
+        self._server_host = px_backend_host if px_backend_host else 'sapi.perimeterx.net' if app_id is None else px_constants.SERVER_URL.format(app_id.lower())
+        self._collector_host = px_backend_host if px_backend_host else 'collector.perimeterx.net' if app_id is None else px_constants.COLLECTOR_URL.format(app_id.lower())
         self._encryption_enabled = config_dict.get('encryption_enabled', True)
         self._sensitive_headers = map(lambda header: header.lower(),
                                       config_dict.get('sensitive_headers', ['cookie', 'cookies']))
@@ -36,7 +37,7 @@ class PxConfig(object):
         self._first_party_xhr_enabled = config_dict.get('first_party_xhr_enabled', True)
         self._ip_headers = config_dict.get('ip_headers', [])
         self._proxy_url = config_dict.get('proxy_url', None)
-        self._max_buffer_len = config_dict.get('max_buffer_len', 30)
+        self._max_buffer_len = max_buffer_len if max_buffer_len > 0 else 1
         self._bypass_monitor_header = config_dict.get('bypass_monitor_header','')
 
         sensitive_routes = config_dict.get('sensitive_routes', [])
@@ -55,7 +56,6 @@ class PxConfig(object):
         self._enforced_specific_routes = enforced_routes
 
         self._block_html = 'BLOCK'
-        self._logo_visibility = 'visible' if custom_logo is not None else 'hidden'
         self._telemetry_config = self.__create_telemetry_config()
         self._testing_mode = testing_mode
         self._auth_token = config_dict.get('auth_token', None)
@@ -169,10 +169,6 @@ class PxConfig(object):
     def block_html(self):
         return self._block_html
 
-    @property
-    def logo_visibility(self):
-        return self._logo_visibility
-
     @property
     def additional_activity_handler(self):
         return self._additional_activity_handler
